@@ -1,3 +1,5 @@
+#' @keywords internal
+"_PACKAGE"
 
 #' @importFrom magrittr %>%
 #' @export
